# Veld

Veld is a suite of command line applications for simple statistics on a data 
stream.

## Installation

Veld is available on PyPI:

```
$ pip install veld
```

## Usage

Documentation on all the commands can be found using:
```
$ man veld <command>
```

## Notes

License: See the LICENSE file.

Author: [Gertjan van den Burg][gertjan]

[gertjan]: https://gertjanvandenburg.com
